# eric7.EricNetwork.EricSslCertificateSelectionDialog

Module implementing a dialog to select a SSL certificate.

### Global Attributes

None

### Classes

EricSslCertificateSelectionDialog | Class implementing a dialog to select a SSL certificate.

### Functions

None

## EricSslCertificateSelectionDialog

Class implementing a dialog to select a SSL certificate.

### Derived from

QDialog, Ui_EricSslCertificateSelectionDialog

### Class Attributes

CertRole

### Class Methods

None

### Methods

EricSslCertificateSelectionDialog | Constructor
__createCaCertificateEntry | Private method to create a certificate entry.
__populateCertificatesTree | Private slot to populate the certificates tree.
getSelectedCertificate | Public method to get the selected certificate.
on_certificatesTree_itemSelectionChanged | Private slot to handle the selection of an item.
on_viewButton_clicked | Private slot to show data of the selected certificate.

### Static Methods

None

#### EricSslCertificateSelectionDialog (Constructor)

EricSslCertificateSelectionDialog(certificates, parent=None)

Constructor

certificates (list of QSslCertificate)
  list of SSL certificates to select from
parent (QWidget)
  reference to the parent widget

#### EricSslCertificateSelectionDialog.__createCaCertificateEntry

__createCaCertificateEntry(cert)

Private method to create a certificate entry.

cert (QSslCertificate)
  certificate to insert

#### EricSslCertificateSelectionDialog.__populateCertificatesTree

__populateCertificatesTree(certificates)

Private slot to populate the certificates tree.

certificates (list of QSslCertificate)
  list of SSL certificates to select from

#### EricSslCertificateSelectionDialog.getSelectedCertificate

getSelectedCertificate()

Public method to get the selected certificate.

Return:
  selected certificate

Return Type:
  QSslCertificate

#### EricSslCertificateSelectionDialog.on_certificatesTree_itemSelectionChanged

on_certificatesTree_itemSelectionChanged()

Private slot to handle the selection of an item.

#### EricSslCertificateSelectionDialog.on_viewButton_clicked

on_viewButton_clicked()

Private slot to show data of the selected certificate.

Up